data = """zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_none|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_simple|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_with_port|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_normalize_case|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_no_normalize_www|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_long_path|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_subdomains|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_https|0.0001
zamboni.mkt.webapps.tests.test_models.TestDomainFromURL.test_empty|0.0001
zamboni.mkt.inapp_pay.tests.test_commands.TestCommand.test_missing_old|0.0002
zamboni.mkt.stats.tests.test_views.TestPadMissingStats.test_group_month|0.0002
zamboni.mkt.stats.tests.test_views.TestPadMissingStats.test_group_week|0.0002
zamboni.mkt.stats.tests.test_views.TestPadMissingStats.test_with_fields|0.0002
zamboni.mkt.stats.tests.test_views.TestPadMissingStats.test_with_date_range|0.0002
zamboni.mkt.inapp_pay.tests.test_models.test_exception_mapping|0.0002
zamboni.mkt.inapp_pay.tests.test_commands.TestCommand.test_missing_new|0.0002
zamboni.mkt.zadmin.tests.test_commands.TestCommand.test_gen_key_existing|0.0002
zamboni.mkt.receipts.tests.test_models.TestBrokenReceipt.test_get_key|0.0002
zamboni.mkt.developers.tests.test_forms.TestPaypalSetupForm.test_email_required|0.0002
zamboni.mkt.carriers.tests.TestCarrierURLs.test_ignore_non_carriers|0.0003
zamboni.mkt.inapp_pay.tests.test_commands.TestCommand.test_empty_key_paths|0.0003
zamboni.mkt.stats.tests.test_views.TestPadMissingStats.test_basic|0.0003
zamboni.mkt.carriers.tests.TestCarrierURLs.test_set_carrier|0.0003
zamboni.mkt.carriers.tests.TestCarrierURLs.test_strip_carrier|0.0003
zamboni.mkt.carriers.tests.TestCarrierURLs.test_context|0.0003
zamboni.mkt.developers.tests.test_forms.TestPaypalSetupForm.test_email_gotten|0.0003
zamboni.mkt.ratings.tests.test_feeds.RatingsFeedTest.test_item_author_name|0.0003
zamboni.mkt.ratings.tests.test_feeds.RatingsFeedTest.test_item_title|0.0003
zamboni.mkt.ratings.tests.test_feeds.FeedTest.test_title|0.0003
zamboni.mkt.site.tests.test_helpers.TestJS.test_prod_unminified_overridden|0.0004
zamboni.mkt.site.tests.test_helpers.TestJS.test_prod_minified|0.0004
zamboni.mkt.carriers.tests.TestCarrierURLs.test_set_carrer_to_none|0.0004
zamboni.mkt.carriers.tests.TestCarrierURLs.test_root_url_ensures_slash|0.0004
zamboni.mkt.ratings.tests.test_feeds.FeedTest.test_item_author_name|0.0004
zamboni.mkt.site.tests.test_helpers.TestJS.test_dev_unminified|0.0004
zamboni.mkt.ratings.tests.test_feeds.FeedTest.test_item_title|0.0004
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_dont_delete_on_exception|0.0004
zamboni.mkt.site.tests.test_helpers.TestJS.test_dev_unminified_overridden|0.0004
zamboni.mkt.developers.tests.test_forms.TestPaypalSetupForm.test_email_malformed|0.0004
zamboni.mkt.ratings.tests.test_feeds.RatingsFeedTest.test_title|0.0004
zamboni.mkt.site.tests.test_helpers.TestCSS.test_prod_unminified_overridden|0.0004
zamboni.mkt.site.tests.test_helpers.TestCSS.test_dev_unminified|0.0004
zamboni.mkt.site.tests.test_helpers.TestCSS.test_prod_minified|0.0004
zamboni.mkt.site.tests.test_helpers.TestCSS.test_dev_unminified_overridden|0.0004
zamboni.mkt.stats.tests.test_tasks.TestCut.test_basic|0.0005
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_reviewed|0.0005
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_not_premium|0.0005
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_url_path|0.0005
zamboni.mkt.webapps.tests.test_crons.TestCleanup.test_not_cleaned|0.0005
zamboni.mkt.site.tests.test_middleware.TestLoginRequiredMiddleware.test_middleware_marketplace_home_skip_redirect|0.0006
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_has_no_premium|0.0006
zamboni.mkt.site.tests.test_middleware.TestLoginRequiredMiddleware.test_middleware_marketplace_login_skip_redirect|0.0006
zamboni.mkt.site.tests.test_middleware.TestLoginRequiredMiddleware.test_middleware|0.0006
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_has_no_price|0.0006
zamboni.mkt.site.tests.test_middleware.TestLoginRequiredMiddleware.test_middleware_marketplace_home_do_redirect|0.0006
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_has_price|0.0006
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_not_json|0.0007
zamboni.mkt.api.tests.test_forms.TestSubmitForm.test_status_public|0.0007
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_not_file|0.0007
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_origin|0.0007
zamboni.mkt.api.tests.test_forms.TestSubmitForm.test_status_null|0.0007
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_no_manifest_at_root|0.0007
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_no_icon_in_manifest|0.0007
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_has_icon_in_manifest|0.0008
zamboni.mkt.webapps.tests.test_crons.TestCleanup.test_cleaned|0.0008
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_cannot_be_purchased|0.0010
zamboni.mkt.zadmin.tests.test_commands.TestCommand.test_gen_key_with_length|0.0010
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_can_be_purchased|0.0010
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_position_missing|0.0010
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_switch_region|0.0012
zamboni.mkt.site.tests.test_helpers.test_login_link|0.0012
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_no_description|0.0012
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_syntax_error|0.0013
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_preview|0.0013
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_switch_locale|0.0013
zamboni.mkt.developers.tests.test_helpers.TestNewDevBreadcrumbs.test_no_args|0.0013
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_utf8_bom|0.0013
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_no_locales|0.0013
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_regions_no_exclusions|0.0015
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_bad_type|0.0015
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_parse_packaged_BOM|0.0015
zamboni.mkt.carriers.tests.TestCarrierURLs.test_reverse|0.0015
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_region_ids_no_exclusions|0.0016
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_stats_url|0.0016
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_preserve_qs_for_region|0.0017
zamboni.mkt.developers.tests.test_helpers.TestDisplayUrl.test_unicode|0.0017
zamboni.mkt.developers.tests.test_helpers.TestDisplayUrl.test_utf8|0.0017
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_non_ascii|0.0018
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_utf16_bom|0.0019
zamboni.mkt.api.tests.test_forms.TestSubmitForm.test_status_other|0.0021
zamboni.mkt.developers.tests.test_helpers.TestNewDevBreadcrumbs.test_with_app|0.0022
zamboni.mkt.developers.tests.test_helpers.test_summarize_validation|0.0025
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_get_page_content|0.0029
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_preserve_qs_for_lang|0.0030
zamboni.mkt.webapps.tests.test_models.TestWebappVersion.test_no_version|0.0030
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_ensure_relative_image_is_absolute|0.0031
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_redirect_for_good_region|0.0031
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_utf32_bom|0.0031
zamboni.mkt.developers.tests.test_helpers.TestNewDevBreadcrumbs.test_with_items|0.0033
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_ensure_relative_link_is_absolute|0.0034
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_redirect_for_good_application|0.0035
zamboni.mkt.site.tests.test_middleware.TestLoginRequiredMiddleware.test_proper_redirects_with_region_stores|0.0036
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_redirect_for_good_locale|0.0036
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_ensure_content_xss_safe|0.0036
zamboni.mkt.developers.tests.test_helpers.TestNewDevBreadcrumbs.test_with_app_and_items|0.0037
zamboni.mkt.ecosystem.tests.test_views.TestLanding.test_legacy_redirect|0.0037
zamboni.mkt.ecosystem.tests.test_views.TestLanding.test_legacy_redirect_with_walled_garden|0.0038
zamboni.mkt.developers.tests.test_views.TestHome.test_login_redirect|0.0040
zamboni.mkt.developers.tests.test_helpers.TestDisplayUrl.test_euc_jp|0.0042
zamboni.mkt.developers.tests.test_helpers.test_hub_page_title|0.0048
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_no_version|0.0051
zamboni.mkt.developers.tests.test_views.TestHome.test_legacy_login_redirect|0.0051
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_url_timeout|0.0053
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_connection_error|0.0053
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_http_error|0.0055
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_no_content_type|0.0056
zamboni.mkt.site.tests.test_views.TestManifest.test_manifest_name|0.0058
zamboni.mkt.developers.tests.test_tasks.TestValidator.test_validation_error|0.0058
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_bad_content_type|0.0058
zamboni.mkt.site.tests.test_views.TestRobots.test_engage_robots|0.0058
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_other_url_error|0.0060
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_success_call_validator|0.0062
zamboni.mkt.developers.tests.test_tasks.TestValidator.test_fail_validation|0.0064
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_response_too_large|0.0064
zamboni.mkt.site.tests.test_views.TestManifest.test_manifest|0.0064
zamboni.mkt.developers.tests.test_tasks.TestValidator.test_pass_validation|0.0067
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_non_utf8_encoding|0.0073
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_success_add_file|0.0075
zamboni.mkt.developers.tests.test_tasks.TestValidator.test_validate_manifest|0.0075
zamboni.mkt.developers.tests.test_tasks.TestValidator.test_validate_packaged_app|0.0079
zamboni.mkt.developers.tests.test_tasks.test_resize_icon_shrink|0.0079
zamboni.mkt.site.tests.test_views.TestMozmarketJS.test_render|0.0079
zamboni.mkt.site.tests.test_views.TestCSRF.test_csrf|0.0080
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_continue_on_404_exception|0.0088
zamboni.mkt.webapps.tests.test_models.TestTransformer.test_addon_transformer_called|0.0089
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_parse_packaged|0.0093
zamboni.mkt.site.tests.test_views.TestRobots.test_do_not_engage_robots|0.0099
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_redirect_for_bad_application|0.0102
zamboni.mkt.site.tests.test_views.Test404.test_404|0.0104
zamboni.mkt.site.tests.test_views.TestMozmarketJS.test_receiptverifier|0.0105
zamboni.mkt.site.tests.test_views.Test404.test_404_consumer_legacy|0.0106
zamboni.mkt.ecosystem.tests.test_views.TestMdnDocumentation.test_mdn_content_unknown|0.0107
zamboni.mkt.account.tests.test_decorators.TestAddonView.test_username|0.0108
zamboni.mkt.developers.tests.test_tasks.TestFetchManifest.test_strip_utf8_bom|0.0122
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_mark_done_pending|0.0134
zamboni.mkt.site.tests.test_views.TestMozmarketJS.test_exclude|0.0143
zamboni.mkt.developers.tests.test_tasks.test_resize_icon_same|0.0145
zamboni.mkt.developers.tests.test_tasks.test_resize_icon_enlarge|0.0146
zamboni.mkt.ecosystem.tests.test_views.TestMdnDocumentation.test_mdn_content_design|0.0150
zamboni.mkt.api.tests.test_forms.TestPreviewForm.test_bad_file|0.0158
zamboni.mkt.ecosystem.tests.test_views.TestMdnDocumentation.test_mdn_content_default|0.0164
zamboni.mkt.ecosystem.tests.test_views.TestMdnDocumentation.test_mdn_content_explicit|0.0165
zamboni.mkt.account.tests.test_decorators.TestAddonView.test_404|0.0165
zamboni.mkt.site.tests.test_middleware.TestVaryMiddleware.test_no_vary_cookie|0.0167
zamboni.mkt.ecosystem.tests.test_views.TestLanding.test_tutorials_default|0.0179
zamboni.mkt.developers.tests.test_tasks.test_resize_image_asset|0.0199
zamboni.mkt.account.tests.test_views.TestAbuse.test_recaptcha|0.0200
zamboni.mkt.developers.tests.test_tasks.test_resize_icon_list|0.0205
zamboni.mkt.account.tests.test_models.TestUserProfile.test_unrestrict|0.0209
zamboni.mkt.developers.tests.test_views_validation.TestWebApps.test_parse|0.0212
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_refresh_mdn_cache|0.0214
zamboni.mkt.api.tests.test_oauth.TestBaseOAuth.test_no_auth|0.0215
zamboni.mkt.developers.tests.test_views.TestHome.test_home_anonymous|0.0217
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_delete_photo_not|0.0224
zamboni.mkt.reviewers.tests.test_views.TestMotd.test_302_for_anonymous|0.0228
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_redirect_for_good_locale_and_region|0.0229
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_nowhere|0.0247
zamboni.mkt.account.tests.test_views.TestAdminAccountSettings.test_forbidden_anon|0.0254
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_auth_required|0.0257
zamboni.mkt.api.tests.test_oauth.TestBaseOAuth.test_request_token_fake|0.0257
zamboni.mkt.ecosystem.tests.test_views.TestDevHub.test_support|0.0258
zamboni.mkt.webapps.tests.test_models.TestTransformer.test_device_type_cache|0.0261
zamboni.mkt.developers.tests.test_tasks.TestRegionExclude.test_exclude_no_apps|0.0265
zamboni.mkt.developers.tests.test_cron.TestExcludeNewRegion.test_not_called_by_default|0.0266
zamboni.mkt.developers.tests.test_tasks.TestRegionExclude.test_exclude_no_regions|0.0267
zamboni.mkt.developers.tests.test_cron.TestExcludeNewRegion.test_called_with_future_exclusions|0.0277
zamboni.mkt.developers.tests.test_tasks.TestRegionExclude.test_exclude_one_new_region|0.0278
zamboni.mkt.api.tests.test_handlers.TestAddValidationHandler.test_verbs|0.0279
zamboni.mkt.ecosystem.tests.test_tasks.TestMdnCacheUpdate.test_refresh_mdn_cache_with_old_data|0.0280
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_by_display_name|0.0281
zamboni.mkt.developers.tests.test_forms.TestInappConfigForm.test_can_override_https|0.0283
zamboni.mkt.developers.tests.test_cron.TestExcludeNewRegion.test_not_called_with_ordinary_exclusions|0.0284
zamboni.mkt.webapps.tests.test_models.TestTransformer.test_device_types|0.0285
zamboni.mkt.developers.tests.test_forms.TestInappConfigForm.test_cannot_override_https|0.0286
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_by_username|0.0287
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_by_username_with_dashes|0.0288
zamboni.mkt.submit.tests.test_models.TestAppSubmissionChecklist.test_default|0.0289
zamboni.mkt.webapps.tests.test_models.TestAddonExcludedRegion.test_unicode|0.0289
zamboni.mkt.ecosystem.tests.test_views.TestMdnDocumentation.test_mdn_content_content|0.0290
zamboni.mkt.webapps.tests.test_models.TestAddonExcludedRegion.test_get_region|0.0293
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_verbs|0.0295
zamboni.mkt.webapps.tests.test_models.TestQueue.test_in_queue|0.0296
zamboni.mkt.submit.tests.test_models.TestAppSubmissionChecklist.test_terms|0.0299
zamboni.mkt.developers.tests.test_cron.TestSendNewRegionEmails.test_called|0.0300
zamboni.mkt.submit.tests.test_models.TestAppSubmissionChecklist.test_manifest|0.0301
zamboni.mkt.developers.tests.test_cron.TestSendNewRegionEmails.test_not_called_with_future_exclusions|0.0302
zamboni.mkt.developers.tests.test_forms.TestRegionForm.test_no_regions|0.0302
zamboni.mkt.submit.tests.test_models.TestAppSubmissionChecklist.test_next_details|0.0303
zamboni.mkt.developers.tests.test_forms.TestRegionForm.test_initial_empty|0.0309
zamboni.mkt.developers.tests.test_cron.TestSendNewRegionEmails.test_not_called_with_exclusions|0.0309
zamboni.mkt.developers.tests.test_tasks.TestRegionExclude.test_exclude_several_new_regions|0.0310
zamboni.mkt.webapps.tests.test_models.TestAddonExcludedRegion.test_remove_excluded|0.0311
zamboni.mkt.submit.tests.test_models.TestAppSubmissionChecklist.test_details|0.0312
zamboni.mkt.webapps.tests.test_models.TestAddonExcludedRegion.test_exclude_multiple|0.0315
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_not_in_category|0.0316
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_by_email|0.0320
zamboni.mkt.developers.tests.test_views.TestTerms.test_login_required|0.0327
zamboni.mkt.account.tests.test_views.TestAccountDelete.test_anonymous|0.0334
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_invalid_receipt|0.0336
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_no_user|0.0339
zamboni.mkt.developers.tests.test_forms.TestRegionForm.test_initial_excluded_in_region|0.0341
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_no_addon|0.0342
zamboni.mkt.account.tests.test_views.TestPreapproval.test_currency_denied|0.0342
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_invalid_signature|0.0343
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_no_cache|0.0344
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_denied|0.0344
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_expired_cert|0.0346
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_geoip_missing_worldwide|0.0347
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_cross_domain|0.0347
zamboni.mkt.developers.tests.test_views_api.TestAPI.test_logged_out|0.0367
zamboni.mkt.developers.tests.test_forms.TestRegionForm.test_initial_excluded_in_regions_and_future_regions|0.0373
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_accept_language_takes_precedence_over_cookie|0.0374
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_verbs|0.0380
zamboni.mkt.api.tests.test_handlers.TestAddValidationHandler.test_missing|0.0381
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_by_id|0.0386
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_get_other_category|0.0388
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_not_found|0.0390
zamboni.mkt.site.tests.test_middleware.TestMobileMiddleware.test_no_effect|0.0394
zamboni.mkt.developers.tests.test_tasks.TestRegionEmail.test_email_for_several_new_regions|0.0395
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_no_cookie|0.0396
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_geoip_missing_lang|0.0399
zamboni.mkt.site.tests.test_middleware.TestMobileMiddleware.test_force_mobile|0.0399
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_not_stuck|0.0400
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_product_wrong_store_data|0.0401
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_user_addon|0.0402
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_product_wrong_type|0.0403
zamboni.mkt.submit.tests.test_views.TestTerms.test_read_dev_agreement_required|0.0403
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_not_review_count|0.0404
zamboni.mkt.api.tests.test_oauth.TestBaseOAuth.test_accepted|0.0404
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_geoip_down|0.0406
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_expired_has_receipt|0.0406
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_geoip_timeout|0.0407
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_check|0.0407
zamboni.mkt.lookup.tests.test_views.TestActivity.test_not_allowed|0.0409
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_not_total|0.0410
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_product_ok_store_data|0.0411
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_review_count|0.0411
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_expired_not_signed|0.0411
zamboni.mkt.developers.tests.test_tasks.TestRegionEmail.test_email_for_two_new_regions|0.0412
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_user_value_incorrect|0.0412
zamboni.mkt.developers.tests.test_tasks.TestRegionEmail.test_email_for_one_new_region|0.0416
zamboni.mkt.site.tests.test_middleware.TestVaryMiddleware.test_no_user_agent|0.0416
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_user_type_incorrect|0.0417
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_not_run|0.0417
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_new_expiry|0.0417
zamboni.mkt.api.tests.test_oauth.TestBaseOAuth.test_request_no_groups_for_you|0.0417
zamboni.mkt.detail.tests.test_views.TestActivity.test_not_allowed|0.0419
zamboni.mkt.api.tests.test_oauth.TestBaseOAuth.test_no_agreement|0.0422
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_total_last_month|0.0423
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_get_category|0.0424
zamboni.mkt.lookup.tests.test_views.TestPurchases.test_not_allowed|0.0425
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_review_last_month|0.0427
zamboni.mkt.lookup.tests.test_views.TestAcctSearch.test_no_results|0.0427
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_log_admin|0.0430
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_garbage_expired|0.0432
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_expired|0.0433
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_log_not_admin|0.0433
zamboni.mkt.api.tests.test_handlers.TestAddValidationHandler.test_fetch|0.0435
zamboni.mkt.site.tests.test_views.Test404.test_404_consumer|0.0435
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_get_categories|0.0435
zamboni.mkt.zadmin.tests.test_views.TestGenerateError.test_metlog_statsd|0.0440
zamboni.mkt.zadmin.tests.test_views.TestGenerateError.test_metlog_json|0.0442
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_accept_language_takes_precedence_over_cookie|0.0443
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_weight|0.0443
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_auth_required|0.0444
zamboni.mkt.site.tests.test_views.Test403.test_403_reviewer|0.0444
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_get_category_localised|0.0447
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_failure|0.0447
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_product_barf_store_data|0.0449
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_recaptcha_shown_for_anonymous|0.0449
zamboni.mkt.api.tests.test_handlers.TestCategoryHandler.test_verbs|0.0451
zamboni.mkt.developers.tests.test_forms.TestPreviewForm.test_preview_other_file_type|0.0453
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_pass|0.0458
zamboni.mkt.developers.tests.test_forms.TestPreviewForm.test_preview_bad_file_type|0.0458
zamboni.mkt.site.tests.test_views.Test403.test_403_admin|0.0460
zamboni.mkt.developers.tests.test_forms.TestPreviewForm.test_preview_good_file_type|0.0466
zamboni.mkt.receipts.tests.test_views.TestReissue.test_reissue_logout|0.0467
zamboni.mkt.api.tests.test_handlers.TestAddValidationHandler.test_bad|0.0469
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_delete_photo|0.0472
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_solitude|0.0476
zamboni.mkt.zadmin.tests.test_views.TestGenerateError.test_metlog_cef|0.0478
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_not_packaged|0.0480
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_404_for_bad_prefix|0.0480
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_reviewers|0.0481
zamboni.mkt.api.tests.test_handlers.TestGetValidationHandler.test_not_owner|0.0489
zamboni.mkt.site.tests.test_views.TestCSRF.test_not_csrf|0.0489
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_webapp|0.0490
zamboni.mkt.account.tests.test_views.TestPreapproval.test_fake_preapproval|0.0492
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_in_region|0.0492
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_not_there|0.0492
zamboni.mkt.zadmin.tests.test_views.TestGenerateError.test_metlog_sentry|0.0501
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_not_there|0.0502
zamboni.mkt.detail.tests.test_views.TestPrivacy.test_policy|0.0502
zamboni.mkt.developers.tests.test_views_api.TestAPI.test_create|0.0505
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_install_src|0.0510
zamboni.mkt.developers.tests.test_forms.TestRegionForm.test_worldwide_only|0.0512
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_lang_region_selector|0.0514
zamboni.mkt.developers.tests.test_views_api.TestAPI.test_delete|0.0519
zamboni.mkt.submit.tests.test_views.TestProceed.test_is_anonymous|0.0521
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_abuse_anonymous_fails|0.0521
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_abuse_anonymous|0.0521
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_not_valid|0.0524
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_not_valid|0.0527
zamboni.mkt.stats.tests.test_views.TestInstalled.test_installed_anon_public|0.0527
zamboni.mkt.developers.tests.test_forms.TestPreviewForm.test_preview_modified|0.0528
zamboni.mkt.stats.tests.test_views.TestInstalled.test_installed_anon|0.0529
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_user_anonymise|0.0530
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_wrong_uid|0.0537
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_not_accepted_tos|0.0541
zamboni.mkt.stats.tests.test_views.TestInstalled.test_installed|0.0542
zamboni.mkt.developers.tests.test_views_api.TestAPI.test_regenerate|0.0551
zamboni.mkt.receipts.tests.test_views.TestReceiptIssue.test_issued_anon|0.0554
zamboni.mkt.account.tests.test_views.TestAccountDelete.test_page|0.0565
zamboni.mkt.account.tests.test_views.TestPreapproval.test_session_cancel|0.0568
zamboni.mkt.receipts.tests.test_views.TestReceiptIssue.test_issued_not_reviewer|0.0571
zamboni.mkt.account.tests.test_views.TestPreapproval.test_fake_preapproval_with_currency|0.0578
zamboni.mkt.submit.tests.test_views.TestProceed.test_is_authenticated|0.0584
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_by_id|0.0594
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_not_yours|0.0597
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_retry_public_keygen_until_unique|0.0598
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_retry_private_keygen_until_unique|0.0598
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_not_in_region|0.0600
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_wrong_key|0.0604
zamboni.mkt.account.tests.test_views.TestPreapproval.test_currency_set|0.0604
zamboni.mkt.developers.tests.test_views.TestHome.test_home_authenticated|0.0606
zamboni.mkt.developers.tests.test_helpers.test_log_action_class|0.0607
zamboni.mkt.developers.tests.test_views.TestTerms.test_accepted|0.0608
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_missing_date_str|0.0609
zamboni.mkt.account.tests.test_views.TestPreapproval.test_session_complete|0.0611
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_no_results|0.0613
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_exhaust_private_keygen_attempts|0.0613
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_exhaust_public_keygen_attempts|0.0613
zamboni.mkt.submit.tests.test_views.TestTerms.test_anonymous|0.0614
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_key_path_cannot_match_sample|0.0615
zamboni.mkt.developers.tests.test_views.TestTerms.test_not_accepted|0.0615
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_generate_private_key|0.0620
zamboni.mkt.submit.tests.test_views.TestManifest.test_anonymous|0.0620
zamboni.mkt.zadmin.tests.test_views.TestEcosystem.test_staff_access|0.0620
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_other_profile|0.0621
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_inapp_stats_url|0.0621
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_encrypt_with_latest_key|0.0623
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_generate_public_key|0.0623
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_app_slug_blocklist|0.0625
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_allowed|0.0629
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_setup|0.0634
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_webapp_type|0.0634
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_in_category|0.0635
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_package_no_version|0.0636
zamboni.mkt.developers.tests.test_views.TestPayPalJS.test_load_paypal_js|0.0641
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_in_region_and_not_in_category|0.0646
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_not_in_region_and_category|0.0646
zamboni.mkt.developers.tests.test_views.TestPayPalJS.test_no_paypal_js|0.0649
zamboni.mkt.webapps.tests.test_models.TestContentRatingsIn.test_in_for_region_and_category|0.0653
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_pin_to_corect_key|0.0653
zamboni.mkt.webapps.tests.test_models.TestContentRatingsIn.test_in_region_and_not_in_category|0.0656
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_encrypted_key_storage|0.0663
zamboni.mkt.webapps.tests.test_models.TestDisabledPayments.test_disable_paid_latest_apps|0.0665
zamboni.mkt.webapps.tests.test_models.TestDisabledPayments.test_disable_paid_popular_apps|0.0666
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_support|0.0666
zamboni.mkt.detail.tests.test_views.TestDetail.test_page|0.0668
zamboni.mkt.account.tests.test_views.TestPreapproval.test_fake_preapproval_no_currency|0.0671
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_active|0.0674
zamboni.mkt.inapp_pay.tests.test_commands.TestCommand.test_migrate|0.0674
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_any_active|0.0675
zamboni.mkt.webapps.tests.test_models.TestDisabledPayments.test_disable_paid_featured_apps|0.0675
zamboni.mkt.submit.tests.test_views.TestTerms.test_disagree|0.0677
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_no_preapproval|0.0677
zamboni.mkt.submit.tests.test_views.TestTerms.test_progress_display|0.0677
zamboni.mkt.submit.tests.test_views.TestTerms.test_page|0.0678
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_get_not_there|0.0678
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_homepage|0.0680
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_install_button_for_anon|0.0683
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_remove_solitude|0.0684
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_cookie_gets_set_once|0.0684
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_no_addon|0.0688
zamboni.mkt.developers.tests.test_tasks.TestGenerateImageAssets.test_get_hue|0.0688
zamboni.mkt.webapps.tests.test_models.TestPackagedSigning.test_not_packaged|0.0692
zamboni.mkt.inapp_pay.tests.test_models.TestInapp.test_any_active_excludes_config_under_edit|0.0692
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_delete_not_there|0.0693
zamboni.mkt.webapps.tests.test_models.TestWebappVersion.test_no_file|0.0693
zamboni.mkt.webapps.tests.test_models.TestPackagedSigning.test_packaged|0.0695
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_cancel|0.0701
zamboni.mkt.webapps.tests.test_models.TestContentRatingsIn.test_not_in_region|0.0701
zamboni.mkt.site.tests.test_views.Test404.test_404_devhub|0.0702
zamboni.mkt.webapps.tests.test_models.TestPackagedSigning.test_packaged_reviewer|0.0704
zamboni.mkt.receipts.tests.test_views.TestReceiptIssue.test_get|0.0712
zamboni.mkt.developers.tests.test_views.TestRemoveLocale.test_bad_request|0.0717
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_developer_comments|0.0718
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_accept_language_takes_precedence_over_previous_request|0.0720
zamboni.mkt.downloads.tests.test_views.TestBlockedDownload.test_download|0.0723
zamboni.mkt.submit.tests.test_views.TestTerms.test_agree|0.0726
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_manage_button_for_anon|0.0730
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_not_webapp|0.0739
zamboni.mkt.account.tests.test_views.TestAdminAccountSettings.test_forbidden|0.0742
zamboni.mkt.developers.tests.test_views.TestUpload.test_login_required|0.0746
zamboni.mkt.developers.tests.test_views.TestRemoveLocale.test_delete_default_locale|0.0748
zamboni.mkt.submit.tests.test_views.TestTerms.test_jump_to_step|0.0752
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_preapproval_enabled|0.0753
zamboni.mkt.submit.tests.test_views.TestManifest.test_page|0.0753
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_remove|0.0756
zamboni.mkt.reviewers.tests.test_views.TestMotd.test_403_for_non_editor|0.0758
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_complete_solitude|0.0762
zamboni.mkt.submit.tests.test_views.TestTerms.test_agree_and_sign_me_up|0.0763
zamboni.mkt.webapps.tests.test_models.TestContentRatingsIn.test_in_region_and_category|0.0765
zamboni.mkt.search.tests.test_api.TestApi.test_wrong_weight|0.0771
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_non_ascii_jwt|0.0772
zamboni.mkt.account.tests.test_views.TestAccountDelete.test_fail|0.0773
zamboni.mkt.purchase.tests.test_views.TestPurchaseDetails.test_pre_approval_not_logged_in|0.0773
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_previews|0.0775
zamboni.mkt.browse.tests.test_views.TestIndexSearch.test_bad_sort_option|0.0780
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_featured_region_exclusions|0.0780
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_category|0.0781
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_sorter|0.0781
zamboni.mkt.submit.tests.test_views.TestManifest.test_progress_display|0.0782
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_no_flash_on_mobile|0.0782
zamboni.mkt.webapps.tests.test_models.TestListedIn.test_in_region_and_category|0.0784
zamboni.mkt.search.tests.test_api.TestApi.test_right_category|0.0784
zamboni.mkt.home.tests.test_views.TestHome.test_no_paypal_js|0.0785
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_garbage_request|0.0785
zamboni.mkt.browse.tests.test_views.TestIndexSearch.test_search_placeholder|0.0786
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_search_category|0.0786
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_featured|0.0787
zamboni.mkt.search.tests.test_api.TestApi.test_wrong_category|0.0787
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_good_cat|0.0789
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_popular|0.0790
zamboni.mkt.search.tests.test_api.TestApi.test_right_category_present|0.0791
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_mangled_json|0.0791
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_search_category|0.0791
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_featured|0.0791
zamboni.mkt.home.tests.test_views.TestHome.test_featured_region_exclusions|0.0791
zamboni.mkt.home.tests.test_views.TestHome.test_load_paypal_js|0.0791
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_bad_cat|0.0794
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_promo|0.0795
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_good_cat|0.0795
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_popular|0.0797
zamboni.mkt.home.tests.test_views.TestHome.test_featured_time_excluded|0.0798
zamboni.mkt.home.tests.test_views.TestHome.test_page|0.0799
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_accept_language_takes_precedence_over_previous_request|0.0799
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_popular_region_exclusions|0.0799
zamboni.mkt.browse.tests.test_views.TestIndexSearch.test_page|0.0799
zamboni.mkt.home.tests.test_views.TestHome.test_featured|0.0800
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_empty_cat|0.0800
zamboni.mkt.browse.tests.test_views.TestIndexSearch.test_sorter|0.0801
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_featured_src|0.0801
zamboni.mkt.home.tests.test_views.TestHome.test_featured_fallback_to_worldwide|0.0803
zamboni.mkt.search.tests.test_api.TestApi.test_wrong_sort|0.0803
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_popular_flash|0.0803
zamboni.mkt.browse.tests.test_views.TestIndexSearch.test_good_sort_option|0.0803
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_sidebar|0.0804
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_featured_src|0.0804
zamboni.mkt.webapps.tests.test_models.TestWebappVersion.test_right_file|0.0804
zamboni.mkt.home.tests.test_views.TestHome.test_popular|0.0804
zamboni.mkt.browse.tests.test_views.TestIndexLanding.test_popular_region_exclusions|0.0804
zamboni.mkt.home.tests.test_views.TestHome.test_featured_src|0.0805
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_other_profile_as_admin|0.0805
zamboni.mkt.home.tests.test_views.TestHome.test_featured_time_included|0.0806
zamboni.mkt.search.tests.test_api.TestApi.test_meta|0.0807
zamboni.mkt.receipts.tests.test_views.TestReissue.test_reissue|0.0809
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_good_cat|0.0809
zamboni.mkt.home.tests.test_views.TestHome.test_popular_region_exclusions|0.0810
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_screenshot_animated|0.0811
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_unknown_app|0.0812
zamboni.mkt.search.tests.test_api.TestApi.test_dehdryate|0.0813
zamboni.mkt.browse.tests.test_views.TestCategorySearch.test_non_indexed_cat|0.0814
zamboni.mkt.site.tests.test_middleware.TestRedirectPrefixedURIMiddleware.test_no_locale|0.0815
zamboni.mkt.search.tests.test_api.TestApi.test_verbs|0.0817
zamboni.mkt.search.tests.test_api.TestApi.test_others_ignored|0.0817
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_device_mobile|0.0818
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_icon_wrong_type|0.0819
zamboni.mkt.receipts.tests.test_views.TestReceiptIssue.test_issued|0.0822
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_adolescent_popularity|0.0825
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_free_and_premium|0.0825
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_price_sort_visible_for_free|0.0826
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_crack_receipt_new_called|0.0829
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_get_bluevia_url|0.0830
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_hide_paid_apps_when_disabled|0.0830
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_require_name|0.0830
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_no_cat|0.0830
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_premium_inapp_only|0.0830
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_app_data_too_long|0.0831
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_page|0.0832
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_region_exclusions|0.0832
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_sort_default|0.0832
zamboni.mkt.browse.tests.test_views.TestCategoryLanding.test_bad_cat|0.0833
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_size_req|0.0834
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_price_sort_visible_for_paid_search|0.0834
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_sort_newest|0.0836
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_sort_rating|0.0838
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_none_expiry|0.0838
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_premium_only|0.0838
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_sort_downloads|0.0838
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_device_tablet|0.0839
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_multiword|0.0841
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_free_and_inapp_only|0.0841
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_case_insensitive|0.0841
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_device_all|0.0842
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_item|0.0842
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_status_works|0.0843
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_redirect_free_price_sort|0.0843
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_known_cat|0.0843
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_status_fails|0.0844
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_invalid_expiry|0.0845
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_by_stem_name|0.0846
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_price_sort_visible_for_paid_browse|0.0847
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_invalid_expiry_non_ascii|0.0847
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_success|0.0847
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_animated|0.0847
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_unknown_cat|0.0848
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_free_other|0.0848
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_expired_iat|0.0848
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_require_price_tier|0.0848
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_cat_from_unreviewed_app|0.0848
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_require_request|0.0848
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_device_desktop|0.0849
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_free_and_premium_inapp|0.0849
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_require_description|0.0849
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_invalid_audience|0.0850
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_premium_dont_check|0.0850
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_empty_name|0.0850
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_preview_status_fails|0.0850
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_none_iat|0.0850
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_malformed_jwt|0.0851
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_premium_addon_purchased|0.0851
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_missing_audience|0.0851
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_name_too_long|0.0851
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_results_sort_unknown|0.0852
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_audience_is_settable|0.0853
zamboni.mkt.search.tests.test_views.TestWebappSearch.test_paid_price_sort|0.0855
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_expired|0.0857
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_by_name_part|0.0857
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_description_too_long|0.0859
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_revoked|0.0860
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_post_required|0.0861
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_ok|0.0862
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_screenshot_wrong_type|0.0863
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_malformed_price_tier|0.0863
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_not_before|0.0864
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_square|0.0865
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_invalid_iat_non_ascii|0.0865
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_ignore_invalid_nbf|0.0866
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_unknown_secret|0.0870
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_app_slugs_separate_from_addon_slugs|0.0871
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_notifies|0.0873
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_premium_addon_not_purchased|0.0873
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_inactive|0.0874
zamboni.mkt.detail.tests.test_views.TestActivity.test_not_even_mine|0.0874
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_unknown_price_tier|0.0875
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_no_recaptcha_for_authenticated|0.0878
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_logged_out|0.0882
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_reviewed_public|0.0886
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_unreviewed_public|0.0890
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_disabled|0.0892
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_unreviewed_lite_and_nominated|0.0895
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_unreviewed_lite|0.0896
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_packaged|0.0897
zamboni.mkt.lookup.tests.test_views.TestActivity.test_not_even_mine|0.0899
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_excluded_regions_not_listed|0.0899
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_other_cats_form_enabled|0.0902
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_regions_listed|0.0907
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_reviewed_lite|0.0907
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_302_for_anonymous|0.0908
zamboni.mkt.developers.tests.test_helpers.TestDevFilesStatus.test_unreviewed_nominated|0.0909
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_premium_addon_refund|0.0909
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_anon|0.0910
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_remove|0.0913
zamboni.mkt.reviewers.tests.test_views.TestMotd.test_perms_not_motd|0.0914
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_empty|0.0916
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_homepage_url_invalid|0.0917
zamboni.mkt.developers.tests.test_views.TestTerms.test_accept|0.0917
zamboni.mkt.lookup.tests.test_views.TestPurchases.test_not_even_mine|0.0917
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_nav_link|0.0929
zamboni.mkt.developers.tests.test_views.TestUpload.test_fileupload_ascii_post|0.0934
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_items|0.0935
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_packaged_icon|0.0938
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_public|0.0940
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_details|0.0943
zamboni.mkt.developers.tests.test_forms.TestFreeToPremium.test_free_to_premium|0.0946
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_edit_support_free_required|0.0947
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_search_matches_type|0.0948
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_user_deleted|0.0950
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_deleted|0.0952
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_ignore_bad_region|0.0953
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_cdn_icon|0.0955
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_excluded_all_regions_not_listed|0.0970
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_abuse_authenticated|0.0972
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_no_video_types|0.0977
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_overview_visible_as_admin|0.0981
zamboni.mkt.ecosystem.tests.test_views.TestDevHub.test_partners|0.0981
zamboni.mkt.receipts.tests.test_views.TestReceiptIssue.test_issued_developer|0.0982
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_good|0.0988
zamboni.mkt.account.tests.test_views.TestAccountDelete.test_success|0.0989
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_games_form_disabled|0.0989
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_video_types|0.0993
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_refresh|0.0994
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_by_guid|0.0994
zamboni.mkt.webapps.tests.test_crons.TestWeeklyDownloads.test_long_ago|0.0994
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_abuse_reports|0.0995
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_not_mine|0.0995
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_soft_delete_items|0.0995
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_inapp_pay_methods|0.0996
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_app_public|0.0997
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_premium_addon_contribution|0.0998
zamboni.mkt.developers.tests.test_views.TestPaymentsProfile.test_checker_no_paypal_id|0.0999
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_conditional_get|0.0999
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_logged_out|0.1000
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_logs|0.1001
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_wrong_uid|0.1003
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_games_form_enabled_with_content_rating|0.1003
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_position_missing|0.1005
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_edit_get_as_admin|0.1008
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_success|0.1009
zamboni.mkt.submit.tests.test_views.TestManifest.test_cannot_skip_prior_step|0.1010
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_already_have_cookie_for_good_region|0.1012
zamboni.mkt.submit.tests.test_views.TestDone.test_anonymous|0.1012
zamboni.mkt.carriers.tests.TestCarrierURLs.test_logout_preserves_carrier|0.1014
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_callback_register|0.1020
zamboni.mkt.developers.tests.test_forms.TestPreviewForm.test_preview_size|0.1025
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_not_instant|0.1027
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_other|0.1028
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_preview_missing|0.1028
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_review_viewing_ping|0.1036
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_edit_post_as_admin|0.1040
zamboni.mkt.account.tests.test_views.TestPreapproval.test_preapproval_complete|0.1043
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_lang_set_with_region|0.1044
zamboni.mkt.developers.tests.test_views_ownership.TestEditWebappAuthors.test_apps_context|0.1047
zamboni.mkt.downloads.tests.test_views.TestBlockedDownload.test_not_webapp|0.1057
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_email_cant_change|0.1060
zamboni.mkt.reviewers.tests.test_views.TestMotd.test_perms_not_editor|0.1062
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_callback_log_in|0.1062
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_no_version|0.1062
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_my_profile_as_anonymous|0.1063
zamboni.mkt.developers.tests.test_views.TestUpload.test_fileupload_validation|0.1065
zamboni.mkt.site.tests.test_middleware.TestMobileMiddleware.test_force_unset_mobile|0.1065
zamboni.mkt.downloads.tests.test_views.TestBlockedDownload.test_disabled|0.1067
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_has_installed|0.1068
zamboni.mkt.account.tests.test_views.TestPreapproval.test_extra_currency|0.1068
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_default_supported_currencies|0.1071
zamboni.mkt.webapps.tests.test_models.TestWebappManager.test_unlisted|0.1072
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_not_reviewer|0.1075
zamboni.mkt.developers.tests.test_views.TestPaymentsProfile.test_checker_solitude|0.1076
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_already_have_cookie_for_bad_locale|0.1076
zamboni.mkt.inapp_pay.tests.test_ipn.TestInappIPN.test_completion|0.1077
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_callback_existing|0.1080
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_authors|0.1087
zamboni.mkt.carriers.tests.TestCarrierURLs.test_slash_redirects_work|0.1094
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_apps_context|0.1095
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_appslug_visible|0.1096
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.bluevia_callback_test|0.1100
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_premium_purchased|0.1100
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_premium_webapp|0.1103
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_premium_disabled|0.1104
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_logs_developer|0.1106
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_install_button_for_owner|0.1108
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_not_purchase|0.1110
zamboni.mkt.detail.tests.test_views.TestDetail.test_manage_button_for_admin|0.1110
zamboni.mkt.webapps.tests.test_models.TestIsComplete.test_no_price|0.1113
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_price|0.1114
zamboni.mkt.purchase.tests.test_bluevia.TestPurchase.test_require_login|0.1119
zamboni.mkt.receipts.tests.test_views.TestReceiptCheck.test_anon|0.1121
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit_default_locale_frontend_error|0.1121
zamboni.mkt.detail.tests.test_views.TestDetail.test_manage_button_for_owner|0.1125
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_manage_button_for_nondev|0.1127
zamboni.mkt.detail.tests.test_views.TestActivity.test_log|0.1130
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_image_status_persona|0.1134
zamboni.mkt.developers.tests.test_views.TestUpload.test_create_fileupload|0.1135
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_pay_methods|0.1136
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_icon_status_no_choice|0.1137
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_install_button_for_reviewer|0.1138
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_encode|0.1141
zamboni.mkt.lookup.tests.test_views.TestActivity.test_access|0.1147
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_deny_secret_to_no_auth|0.1149
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_devices_listed|0.1150
zamboni.mkt.lookup.tests.test_views.TestActivity.test_log|0.1154
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_disabled_by_user|0.1154
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_some_supported_currencies|0.1158
zamboni.mkt.webapps.tests.test_models.TestIsComplete.test_price|0.1164
zamboni.mkt.developers.tests.test_views.TestUpload.test_redirect|0.1166
zamboni.mkt.developers.tests.test_views_payments.TestInappConfigReset.test_reset_requires_auth|0.1166
zamboni.mkt.reviewers.tests.test_views.TestMotd.test_motd_change|0.1174
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_form_url|0.1175
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_no_engaged_robots_for_disabled|0.1179
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_blocked_by_mozilla|0.1180
zamboni.mkt.submit.tests.test_views.TestManifest.test_jump_to_step|0.1180
zamboni.mkt.lookup.tests.test_views.TestAppSummaryRefunds.test_no_refunds|0.1180
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_disabled_by_mozilla|0.1183
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_public_waiting|0.1184
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_post_preview|0.1185
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_rejected|0.1186
zamboni.mkt.inapp_pay.tests.test_verify.TestVerify.test_non_public_app|0.1186
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_incomplete|0.1189
zamboni.mkt.developers.tests.test_views.TestUpload.test_fileupload_user|0.1192
zamboni.mkt.lookup.tests.test_views.TestPurchases.test_access|0.1194
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_pending|0.1200
zamboni.mkt.developers.tests.test_views.TestPublicise.test_logout|0.1202
zamboni.mkt.developers.tests.test_views.TestUploadDetail.test_detail_json|0.1202
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_nonexistent_txn|0.1205
zamboni.mkt.developers.tests.test_views_edit.TestEditTechnical.test_form_url|0.1205
zamboni.mkt.purchase.tests.test_bluevia.TestPostback.test_invalid|0.1215
zamboni.mkt.purchase.tests.test_bluevia_refund.TestRefund.test_not_mine|0.1221
zamboni.mkt.purchase.tests.test_bluevia.TestPostback.test_unknown_contrib|0.1222
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_nonexistent_txn_no_really|0.1223
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_preview_status_works|0.1225
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_parsed|0.1225
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_crack_receipt|0.1229
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_crack_borked_receipt|0.1230
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_other_categories_are_not_excluded|0.1230
zamboni.mkt.zadmin.tests.test_views.TestAddonSearch.test_lookup_addon|0.1235
zamboni.mkt.detail.tests.test_views.TestPrivacy.test_policy_html|0.1241
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_refresh_dev_only|0.1247
zamboni.mkt.developers.tests.test_views.TestProfile.test_without_contributions_labels|0.1254
zamboni.mkt.developers.tests.test_views.TestRefunds.test_anonymous|0.1255
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_data|0.1255
zamboni.mkt.zadmin.tests.test_views.TestAddonSearch.test_lookup_addon_redirect|0.1258
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_xss|0.1262
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit_locale|0.1263
zamboni.mkt.purchase.tests.test_bluevia_refund.TestPostback.test_purchased|0.1264
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_signer|0.1268
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt|0.1270
zamboni.mkt.search.tests.test_views.TestFilterMobileCompat.test_mobile_no_flash|0.1271
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_get_webapp|0.1281
zamboni.mkt.search.tests.test_views.TestFilterMobileCompat.test_generator|0.1281
zamboni.mkt.developers.tests.test_forms.TestFreeToPremium.test_free_to_premium_pending|0.1283
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_premium_price_initial_use_default|0.1285
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_show_secret|0.1285
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_mozilla_contact_invalid|0.1286
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_flash_unset_view|0.1287
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_theme_images|0.1287
zamboni.mkt.lookup.tests.test_views.TestAppSummaryRefunds.test_auto_approved|0.1289
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json_encoding_empty|0.1291
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_viewer_post|0.1292
zamboni.mkt.detail.tests.test_views.TestDetail.test_free_install_button_for_dev|0.1293
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_ignore_valid_image|0.1294
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_form_url|0.1296
zamboni.mkt.developers.tests.test_views_payments.TestInappConfigReset.test_reset_non_existant_config|0.1296
zamboni.mkt.account.tests.test_views.TestProfileSections.test_my_submissions_no_pagination|0.1300
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_missing_pay_request_on_start|0.1303
zamboni.mkt.lookup.tests.test_views.TestAppSummaryRefunds.test_approved|0.1308
zamboni.mkt.purchase.tests.test_bluevia.TestPostback.test_invalid_claim|0.1313
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_24_hr|0.1314
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_missing_pay_request|0.1315
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_public|0.1316
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_absolute_url|0.1318
zamboni.mkt.developers.tests.test_views.TestUploadDetail.test_detail_for_free_extension_webapp|0.1319
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_image_status_default|0.1319
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_my_profile|0.1319
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_add_hash|0.1320
zamboni.mkt.developers.tests.test_forms.TestFreeToPremium.test_premium_to_free|0.1321
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json|0.1326
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json_unicode|0.1335
zamboni.mkt.search.tests.test_views.TestFilterMobileCompat.test_mobile_applied_filters|0.1336
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_anonymous_delete_redirects|0.1339
zamboni.mkt.developers.tests.test_views.TestRemoveLocale.test_success|0.1347
zamboni.mkt.lookup.tests.test_views.TestAppSearch.test_by_random_guid|0.1350
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json_traceback_in_response|0.1354
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_not_reviewer|0.1357
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_deny_inactive_secrets|0.1357
zamboni.mkt.detail.tests.test_views.TestActivity.test_access|0.1357
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_get_or_create|0.1359
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_request_issue|0.1363
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_install_button_for_anon|0.1364
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_form_url|0.1366
zamboni.mkt.receipts.tests.test_views.TestReceiptCheck.test_not_there|0.1366
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_non_refundable_txn|0.1367
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_ratings_edit_add_dupe|0.1367
zamboni.mkt.lookup.tests.test_views.TestAppSummaryRefunds.test_rejected|0.1367
zamboni.mkt.developers.tests.test_views.TestPaymentsProfile.test_checker_error|0.1369
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_no_preapproval_anonymous|0.1369
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_blocked_app|0.1376
zamboni.mkt.site.tests.test_views.Test403.test_403_devhub|0.1379
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_blocked|0.1383
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit_xss|0.1385
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_edit_no_post_as_nonadmin|0.1386
zamboni.mkt.webapps.tests.test_models.TestIsComplete.test_paypal|0.1393
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_privacy_policy_xss|0.1395
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_video_add_hash_switch_off|0.1398
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_support_email|0.1400
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_pending|0.1400
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_7_days|0.1402
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_overview_forbidden_for_nonadmin|0.1402
zamboni.mkt.developers.tests.test_views.TestEditPayments.test_upsell|0.1404
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_403_for_non_editor|0.1406
zamboni.mkt.developers.tests.test_views.TestUploadDetail.test_detail_view|0.1410
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_flash_set_view|0.1411
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_support_url|0.1413
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_bad_urls|0.1415
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_disabled_by_user|0.1416
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_description|0.1417
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_non_packaged|0.1418
zamboni.mkt.lookup.tests.test_views.TestAppSummaryRefunds.test_requested|0.1420
zamboni.mkt.lookup.tests.test_views.TestPurchases.test_purchase_shows_up|0.1421
zamboni.mkt.developers.tests.test_views_edit.TestEditTechnical.test_log|0.1424
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_data_developer|0.1425
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_edit_no_get_as_nonadmin|0.1427
zamboni.mkt.developers.tests.test_views_paypal.TestPaypal.test_paypal_setup_json|0.1429
zamboni.mkt.receipts.tests.test_views.TestReceiptCheck.test_there|0.1430
zamboni.mkt.developers.tests.test_views_edit.TestEditListingWebapp.test_apps_context|0.1430
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_request_issue_inapp|0.1430
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_app_pending|0.1430
zamboni.mkt.submit.tests.test_views.TestDone.test_progress_display|0.1432
zamboni.mkt.developers.tests.test_views_edit.TestEditListingWebapp.test_nav_links|0.1435
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_required_fields|0.1435
zamboni.mkt.developers.tests.test_views.TestPaymentsProfile.test_checker_pass|0.1436
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_ignore_older_than_24_hours|0.1438
zamboni.mkt.developers.tests.test_views.TestAppBreadcrumbs.test_regular_breadcrumbs|0.1438
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_soft_deleted_valid|0.1441
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_delete_link|0.1444
zamboni.mkt.receipts.tests.test_views.TestReissue.test_reissue_premium_not_purchased|0.1445
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_view_state_when_not_configured|0.1445
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_ignore_older_than_7_days|0.1448
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_summary_no_description|0.1452
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_developer_comments|0.1456
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_data_reviewer|0.1459
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_details|0.1461
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_confirm|0.1462
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_reads_solitude|0.1463
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_is_premium_webapp_foreign|0.1463
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_video_size|0.1465
zamboni.mkt.lookup.tests.test_views.TestAppDownloadSummary.test_ignore_older_than_7_days|0.1467
zamboni.mkt.lookup.tests.test_views.TestAppDownloadSummary.test_7_days|0.1467
zamboni.mkt.receipts.tests.test_views.TestReceiptVerify.test_not_there|0.1469
zamboni.mkt.receipts.tests.test_views.TestReissue.test_reissue_premium_purchased|0.1469
zamboni.mkt.lookup.tests.test_views.TestAppDownloadSummary.test_24_hours|0.1473
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_invalid_pay_request|0.1477
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_reads_solitude_but_empty|0.1480
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_homepage|0.1480
zamboni.mkt.purchase.tests.test_views.TestPurchaseDetails.test_pre_approval|0.1482
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_verbose_error|0.1484
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_my_profile_as_other_user|0.1486
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_delete_redirect_to_dashboard|0.1490
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_form_url|0.1490
zamboni.mkt.lookup.tests.test_views.TestAppDownloadSummary.test_ignore_older_than_24_hours|0.1491
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_ratings_view|0.1493
zamboni.mkt.lookup.tests.test_views.TestAppSummary.test_visible_authors|0.1493
zamboni.mkt.detail.tests.test_views.TestDetail.test_manage_button_for_dev|0.1494
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_hide_inactive_keys|0.1494
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_delete_nonincomplete|0.1495
zamboni.mkt.webapps.tests.test_crons.TestWeeklyDownloads.test_recently|0.1496
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_viewing_my_profile_as_admin|0.1504
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_video_add_hash|0.1504
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_viewer_get|0.1518
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_delete_redirect_to_dashboard_with_qs|0.1518
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_edit_support_premium_required|0.1520
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_cannot_review_my_app|0.1522
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_get|0.1526
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_manifest_url_changed|0.1529
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_exclude_future_regions|0.1542
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_categories_listed|0.1543
zamboni.mkt.developers.tests.test_views_edit.TestPromoUpload.test_add|0.1555
zamboni.mkt.submit.tests.test_views.TestDetails.test_anonymous|0.1556
zamboni.mkt.submit.tests.test_views.TestDone.test_done|0.1558
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json_encoding|0.1559
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_include_future_regions|0.1561
zamboni.mkt.lookup.tests.test_views.TestAppDownloadSummary.test_alltime_dl|0.1565
zamboni.mkt.purchase.tests.test_bluevia.TestPurchase.test_pay_status_for_unknown_contrib|0.1566
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_key_gen_is_per_app|0.1567
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_fetch_ok|0.1567
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_set_flash|0.1571
zamboni.mkt.developers.tests.test_views.TestDelete.test_post|0.1575
zamboni.mkt.account.tests.test_views.TestAccountSettings.test_no_password_changes|0.1578
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_include_regions|0.1579
zamboni.mkt.developers.tests.test_views.TestRefunds.test_bad_owner|0.1584
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_ignore_error|0.1585
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_free|0.1587
zamboni.mkt.detail.tests.test_views.TestActivity.test_display|0.1589
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_error|0.1600
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_get|0.1600
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_unicode_error|0.1601
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_ignore_bad_status|0.1603
zamboni.mkt.purchase.tests.test_bluevia.TestPostback.test_valid|0.1604
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_screenshot_required|0.1604
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_not_logged_in|0.1605
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_non_ascii_invalid_uuid|0.1610
zamboni.mkt.detail.tests.test_views.TestReportAbuse.test_abuse_name|0.1610
zamboni.mkt.developers.tests.test_views_edit.TestEditTechnical.test_devcomment_optional|0.1611
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_missing_uuid|0.1613
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_unicode_default|0.1613
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_7_days|0.1614
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_alltime|0.1615
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_wrong_uuid|0.1616
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_cancel|0.1618
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_refetch_old_image|0.1619
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_ignore_older_than_24_hr|0.1621
zamboni.mkt.lookup.tests.test_views.TestActivity.test_display|0.1623
zamboni.mkt.receipts.tests.test_views.TestReceiptCheck.test_not_reviewer|0.1624
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_not_inapp|0.1626
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_ignore_older_than_7_days|0.1632
zamboni.mkt.developers.tests.test_views.TestRefunds.test_admin|0.1633
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_zero|0.1635
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_include_all_and_future_regions|0.1635
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_delete|0.1644
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_screenshot_video_required|0.1645
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_deny_secret_to_non_owner|0.1646
zamboni.mkt.purchase.tests.test_bluevia.TestPurchaseJWT.test_keys|0.1647
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_homepage_url_optional|0.1650
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_has_purchased|0.1651
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_update_existing_image|0.1652
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_split|0.1653
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_no_status_bar|0.1657
zamboni.mkt.developers.tests.test_views.TestResumeStep.test_no_step_redirect|0.1663
zamboni.mkt.purchase.tests.test_bluevia.TestPurchaseJWT.test_prices|0.1664
zamboni.mkt.developers.tests.test_views_paypal.TestPaypal.test_partial_submit|0.1664
zamboni.mkt.purchase.tests.test_bluevia.TestPurchaseJWT.test_usd_for_usa|0.1665
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_edit_support|0.1666
zamboni.mkt.webapps.tests.test_crons.TestWeeklyDownloads.test_weekly_downloads|0.1666
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_games_with_content_rating|0.1668
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_notify_timeout|0.1670
zamboni.mkt.developers.tests.test_views_payments.TestInappConfigReset.test_reset_requires_owner|0.1672
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_retry_http_error|0.1674
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_games_excluded|0.1675
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_signed_app_response|0.1677
zamboni.mkt.developers.tests.test_views_ownership.TestEditWebappAuthors.test_success_add_owner|0.1677
zamboni.mkt.purchase.tests.test_bluevia.TestPurchaseJWT.test_claims|0.1678
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_edit_support_url_optional|0.1680
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_notify_reversal_chargeback|0.1681
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_currency|0.1690
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_ajax|0.1690
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_disabled_by_mozilla|0.1690
zamboni.mkt.lookup.tests.test_views.TestPurchases.test_no_support_link|0.1692
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_pending|0.1693
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_blocked_by_mozilla|0.1695
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_configurable_https|0.1695
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_disabled_by_user|0.1695
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_bad_status|0.1696
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_disabled_post_dev|0.1697
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_total_few|0.1698
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_configurable_http|0.1700
zamboni.mkt.developers.tests.test_models.TestActivityLogCount.test_review_count_few|0.1701
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_incomplete|0.1702
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval_empty|0.1703
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_delete_not_mine|0.1704
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_any_error|0.1705
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_rejected|0.1706
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_invalid_app_response|0.1711
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_unset_flash|0.1712
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_default_currency|0.1713
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_redirect|0.1714
zamboni.mkt.api.tests.test_handlers.TestPreviewHandler.test_get_not_mine|0.1715
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_premium_price_initial_already_set|0.1717
zamboni.mkt.submit.tests.test_views.TestDetails.test_resume_later|0.1718
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_form_url|0.1720
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_force_https|0.1720
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_staff|0.1721
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_disabled_by_user|0.1725
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_different|0.1726
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_pending|0.1727
zamboni.mkt.developers.tests.test_views.TestResumeStep.test_step_redirects|0.1728
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_owner_public_waiting|0.1730
zamboni.mkt.developers.tests.test_views.TestRefunds.test_viewer|0.1730
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_ajax_solitude|0.1732
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_accept_language_and_cookies|0.1732
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_invalid_currency|0.1734
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_contribution|0.1738
zamboni.mkt.account.tests.test_models.TestUserProfile.test_restrict|0.1739
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_region_ids_with_exclusions|0.1742
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_incomplete|0.1743
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_notify_pay|0.1749
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_verbose_paypal_error|0.1749
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_disabled_by_mozilla|0.1751
zamboni.mkt.developers.tests.test_views.TestRefunds.test_empty_queues|0.1752
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_get_regions_with_exclusions|0.1752
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_brazil_games_already_excluded|0.1759
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval_disagree|0.1761
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_blocked_by_mozilla|0.1763
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_mozilla_contact|0.1766
zamboni.mkt.submit.tests.test_views.TestCreateWebAppFromManifest.test_duplicate_domain_from_js|0.1767
zamboni.mkt.developers.tests.test_views.TestRefunds.test_empty_tables|0.1768
zamboni.mkt.developers.tests.test_views.TestRefunds.test_owner|0.1771
zamboni.mkt.inapp_pay.tests.test_tasks.TestNotifyApp.test_notify_refund_chargeback|0.1771
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_rejected|0.1776
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_ignore_bad_locale|0.1776
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_admin_public_waiting|0.1777
zamboni.mkt.account.tests.test_views.TestProfileLinks.test_username|0.1784
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_free|0.1786
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_public_app|0.1786
zamboni.mkt.developers.tests.test_views.TestPublicise.test_publicise|0.1788
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_refund_failed|0.1793
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_rereview_to_escalation|0.1799
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_paykey_exception|0.1803
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_reviews|0.1804
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_24_hours|0.1804
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_contrib_tier_usd|0.1804
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_invalid_contrib_uuid|0.1805
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_unverified_preauth|0.1805
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_ratings_edit_add|0.1808
zamboni.mkt.inapp_pay.tests.test_views.TestProductImage.test_show_default|0.1809
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_install_button_for_owner|0.1811
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_premium_fails|0.1811
zamboni.mkt.developers.tests.test_views.TestProfile.test_log|0.1811
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_empty_preapproval|0.1816
zamboni.mkt.purchase.tests.test_bluevia.TestPurchase.test_prepare_pay|0.1818
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_no_preapproval|0.1820
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_disabled_payments_action_links|0.1820
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_app_slug_collision|0.1823
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit_exclude_optional_fields|0.1826
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_non_author_no_delete_for_you|0.1832
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_contribution_client_data|0.1835
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_contrib_tier_non_usd|0.1835
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_status_bar_no_contrib|0.1847
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_escalation|0.1849
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_app_pending_author|0.1851
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_already_refunded_solitude|0.1856
zamboni.mkt.submit.tests.test_views.TestDetails.test_not_owner|0.1856
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_preapproval_sets_currency|0.1856
zamboni.mkt.ratings.tests.test_views.TestFlag.test_no_login|0.1860
zamboni.mkt.inapp_pay.tests.test_ipn.TestInappIPN.test_refund|0.1861
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_logged_out|0.1861
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_incomplete_app|0.1861
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_locale_sets_currency|0.1867
zamboni.mkt.developers.tests.test_views.TestRefunds.test_support|0.1870
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_key_generation|0.1871
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_keys_are_preserved_on_edit|0.1871
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_urls_solitude|0.1872
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_delete_incomplete|0.1874
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_viewer_lacks_access|0.1874
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_status_bar_with_contrib|0.1878
zamboni.mkt.purchase.tests.test_bluevia.TestPurchase.test_status_for_purchases_only|0.1883
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_pay_error_no_app_id|0.1884
zamboni.mkt.inapp_pay.tests.test_ipn.TestInappIPN.test_reversal|0.1895
zamboni.mkt.developers.tests.test_views_paypal.TestPaypal.test_bounce_solitude|0.1901
zamboni.mkt.reviewers.tests.test_views.TestGetSigned.test_not_logged_in|0.1901
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_paid_public_install_button_for_reviewer|0.1907
zamboni.mkt.developers.tests.test_views_payments.TestInappConfig.test_regenerate_keys_when_inactive|0.1915
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_preauth_ok|0.1918
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_pay_start|0.1919
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_changes|0.1925
zamboni.mkt.inapp_pay.tests.test_tasks.TestFetchProductImage.test_ignore_non_image|0.1928
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_switch_owner|0.1941
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_developer|0.1942
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_initial_free|0.1947
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_no_preapproval_authenticated|0.1950
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_form_action_on_status_page|0.1951
zamboni.mkt.purchase.tests.test_purchase_order.TestPurchaseIPNOrder.test_ipn_no_result|0.1957
zamboni.mkt.submit.tests.test_views.TestCreateWebAppFromManifest.test_duplicate_domain|0.1961
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_not_log|0.1962
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_manifest_json_packaged|0.1975
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_install_premium|0.1981
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_pay_complete|0.1983
zamboni.mkt.account.tests.test_views.TestAbuse.test_no_recaptcha|0.1984
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_install_button_for_dev|0.1997
zamboni.mkt.detail.tests.test_views.TestDetail.test_paid_preapproval_enabled|0.1997
zamboni.mkt.zadmin.tests.test_views.TestAddonAdmin.test_no_webapps|0.2000
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit|0.2005
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_comment|0.2009
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_escalated|0.2012
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_premium_only|0.2015
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_addon_purchase|0.2032
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_no_api_key|0.2042
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval_used|0.2044
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval|0.2053
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_purchase_logs|0.2055
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_dev_post|0.2059
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_summary_max_length|0.2062
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_receipt_no_node|0.2081
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_link_visitor|0.2083
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_rereview|0.2092
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_name_required|0.2097
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_premium_passes|0.2100
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_name_max_length|0.2102
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_abuse|0.2104
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_free_in_app_passes|0.2108
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_purchase|0.2109
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_dev_get|0.2111
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_clear_escalation|0.2115
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_name_required_for_all_whitespace|0.2117
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_must_have_owner_delete|0.2117
zamboni.mkt.purchase.tests.test_purchase_order.TestPurchaseIPNOrder.test_result|0.2127
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_required|0.2129
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_must_have_listed|0.2129
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_edit_manifest_url_empty|0.2131
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_check_solitude|0.2143
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_clear_rereview|0.2143
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_slug_invalid|0.2144
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_premium_in_app_passes|0.2149
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_must_have_owner|0.2151
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_addon_premium|0.2160
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_nonexistent|0.2165
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_slug_max_length|0.2166
zamboni.mkt.ratings.tests.test_views.TestCreate.test_restrict|0.2168
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval_solitude|0.2168
zamboni.mkt.purchase.tests.test_bluevia.TestPurchase.test_pay_status|0.2170
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_author_support_role|0.2171
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_issue_error|0.2171
zamboni.mkt.ratings.tests.test_views.TestFlag.test_new_flag|0.2172
zamboni.mkt.reviewers.tests.test_views.TestGetSigned.test_not_reviewer|0.2180
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_issue_logs|0.2183
zamboni.mkt.developers.tests.test_views_payments.TestInappConfigReset.test_reset|0.2194
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_dev|0.2196
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_devices_add_required|0.2198
zamboni.mkt.developers.tests.test_views_ownership.TestDeveloperRoleAccess.test_enable|0.2198
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_decline_logs|0.2199
zamboni.mkt.purchase.tests.test_bluevia_tasks.TestNotify.test_no_postback_when_not_configured|0.2201
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_issue_solitude|0.2201
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_issue|0.2204
zamboni.mkt.developers.tests.test_views.TestResumeStep.test_resume_without_checklist|0.2205
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_issue_solitude_error|0.2212
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_apps_decline|0.2220
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_items_packaged|0.2221
zamboni.mkt.developers.tests.test_views_edit.TestEditSupport.test_edit_support_premium|0.2230
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_pay_error_no_support|0.2232
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_not_paypal_updates|0.2233
zamboni.mkt.developers.tests.test_views.TestDelete.test_post_not|0.2244
zamboni.mkt.site.tests.test_helpers.TestMarketButton.test_packaged_no_valid_status|0.2245
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_logged|0.2247
zamboni.mkt.detail.tests.test_views.TestDetail.test_review_history_button_for_reviewers|0.2248
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_more_information|0.2250
zamboni.mkt.developers.tests.test_views.TestDevRequired.test_disabled_post_admin|0.2257
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_ignore_not_webapp|0.2257
zamboni.mkt.ratings.tests.test_views.TestCreate.test_no_rating|0.2271
zamboni.mkt.detail.tests.test_views.TestDetail.test_no_paid_pending_install_button_for_reviewer|0.2274
zamboni.mkt.downloads.tests.test_views.TestDownload.test_not_webapp|0.2290
zamboni.mkt.lookup.tests.test_views.TestAppSummaryPurchases.test_ignore_non_purchases|0.2292
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_payments_page|0.2294
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_link_logged|0.2296
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_later_then_free_with_paypal_id|0.2302
zamboni.mkt.developers.tests.test_views.TestPublicise.test_status|0.2304
zamboni.mkt.purchase.tests.test_bluevia_tasks.TestNotify.test_retry|0.2317
zamboni.mkt.developers.tests.test_views_paypal.TestPayments.test_later_then_free|0.2320
zamboni.mkt.developers.tests.test_views_edit.TestPromoUpload.test_delete|0.2326
zamboni.mkt.purchase.tests.test_bluevia_tasks.TestNotify.test_postback|0.2327
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_max|0.2328
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_add_user_twice|0.2329
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_authors|0.2344
zamboni.mkt.downloads.tests.test_views.TestDownload.test_disabled_but_owner|0.2359
zamboni.mkt.inapp_pay.tests.test_views.TestPayStart.test_pay_start_error|0.2362
zamboni.mkt.receipts.tests.test_verify.TestVerify.test_other_premiums|0.2369
zamboni.mkt.webapps.tests.test_models.TestIsComplete.test_fail|0.2381
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_no_preapproval_non_us_locale|0.2386
zamboni.mkt.reviewers.tests.test_views.TestGetSigned.test_reviewer|0.2388
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_accept_good_region|0.2390
zamboni.mkt.reviewers.tests.test_views.TestGetSigned.test_wrong_version|0.2400
zamboni.mkt.inapp_pay.tests.test_views.TestProductImage.test_show_image|0.2404
zamboni.mkt.submit.tests.test_views.TestDetails.test_page|0.2406
zamboni.mkt.developers.tests.test_views_bluevia.TestBlueVia.test_bluevia_remove_error|0.2407
zamboni.mkt.inapp_pay.tests.test_views.TestProductImage.test_handle_multiple|0.2420
zamboni.mkt.submit.tests.test_views.TestDetails.test_no_video_types|0.2425
zamboni.mkt.submit.tests.test_views.TestDetails.test_progress_display|0.2427
zamboni.mkt.downloads.tests.test_views.TestDownload.test_download|0.2428
zamboni.mkt.downloads.tests.test_views.TestDownload.test_disabled_but_admin|0.2435
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_stale_refund|0.2449
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_reply_edit|0.2452
zamboni.mkt.submit.tests.test_views.TestDetails.test_video_types|0.2457
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_no_preapproval|0.2458
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_already_refunded|0.2460
zamboni.mkt.submit.tests.test_views.TestDetails.test_device_types_default|0.2474
zamboni.mkt.detail.tests.test_views.TestDetail.test_has_summary|0.2481
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_disable|0.2485
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_rereview_to_disable|0.2505
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_paypal_updates|0.2538
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_escalation_to_disable|0.2538
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_ignore_disabled|0.2558
zamboni.mkt.purchase.tests.test_purchase_order.TestPurchaseIPNOrder.test_ipn_then_result|0.2564
zamboni.mkt.ratings.tests.test_views.TestCreate.test_no_body|0.2572
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_ignore_pending|0.2579
zamboni.mkt.themes.tests.test_views.TestSubmitTheme.test_submit_theme|0.2594
zamboni.mkt.reviewers.tests.test_views.TestMiniManifestView.test_not_logged_in|0.2594
zamboni.mkt.themes.tests.test_views.TestSubmitTheme.test_blank_fields|0.2601
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_support_has_access|0.2619
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_slug_valid|0.2640
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_success_delete_user|0.2642
zamboni.mkt.ratings.tests.test_views.TestListing.test_actions_as_author|0.2677
zamboni.mkt.detail.tests.test_views.TestPrivacy.test_app_statuses|0.2686
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_xss|0.2690
zamboni.mkt.ratings.tests.test_views.TestCreate.test_premium_no_add_review_link_visitor|0.2692
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_no_abuses_no_history|0.2694
zamboni.mkt.ratings.tests.test_views.TestListing.test_items|0.2701
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_receipt_has_node|0.2702
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_dev_has_access|0.2706
zamboni.mkt.developers.tests.test_views_edit.TestEditTechnical.test_toggles|0.2711
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_validation_error_logs|0.2729
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_addon_free|0.2734
zamboni.mkt.purchase.tests.test_bluevia.TestPurchaseJWT.test_brl_for_brazil|0.2757
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_log|0.2757
zamboni.mkt.ratings.tests.test_views.TestListing.test_empty_list|0.2758
zamboni.mkt.ratings.tests.test_views.TestCreate.test_not_review_purchased|0.2766
zamboni.mkt.reviewers.tests.test_views.TestGetSigned.test_not_packaged|0.2777
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_pre_approval_no_ajax|0.2780
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_success_add_user|0.2791
zamboni.mkt.account.tests.test_views.TestProfileSections.test_my_reviews|0.2794
zamboni.mkt.detail.tests.test_views.TestPackagedManifest.test_app_pending_reviewer|0.2796
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_exclude_games_in_brazil|0.2799
zamboni.mkt.detail.tests.test_views.TestDetail.test_disabled_payments_notice|0.2800
zamboni.mkt.ratings.tests.test_views.TestListing.test_actions_as_admin|0.2802
zamboni.mkt.ratings.tests.test_views.TestCreate.test_delete_reply|0.2818
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_l10n_not_us|0.2826
zamboni.mkt.ratings.tests.test_feeds.RatingsFeedTest.test_rss_page|0.2843
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_games_already_excluded_in_brazil|0.2843
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_defaulticon|0.2844
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_check_description|0.2848
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_manifest_name_change_rereview|0.2851
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_video_add_switch_off|0.2852
zamboni.mkt.purchase.tests.test_purchase_order.TestPurchaseIPNOrder.test_result_then_ipn|0.2857
zamboni.mkt.developers.tests.test_tasks.TestGenerateImageAssets.test_use_64|0.2858
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preuploadedicon|0.2873
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit|0.2887
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_slug_success|0.2891
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_link_plural|0.2891
zamboni.mkt.ratings.tests.test_views.TestListing.test_actions_as_admin_and_author|0.2895
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_link_singular|0.2902
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_link_dev|0.2904
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_devices_add|0.2938
zamboni.mkt.developers.tests.test_tasks.TestGenerateImageAssets.test_generated_image_assets|0.2944
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_fresh_refund|0.2954
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_slug_dupe|0.2957
zamboni.mkt.webapps.tests.test_models.TestWebappManager.test_listed|0.2961
zamboni.mkt.ratings.tests.test_views.TestCreate.test_premium_no_add_review_link_logged|0.2975
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_add|0.2975
zamboni.mkt.reviewers.tests.test_views.TestMiniManifestView.test_not_reviewer|0.2980
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_l10n|0.2994
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_categories_addandremove|0.3005
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_no_refunds|0.3009
zamboni.mkt.ratings.tests.test_views.TestCreate.test_premium_no_add_review_link|0.3009
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_permissions_token_different_email|0.3013
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_unrated_pending_brazil_game|0.3016
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_public|0.3021
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_devices_addandremove|0.3045
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_video_add|0.3057
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_abuse_no_history|0.3069
zamboni.mkt.ratings.tests.test_views.TestCreate.test_premium_add_review_link|0.3069
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_summary_auth|0.3081
zamboni.mkt.developers.tests.test_views_edit.TestAdminSettings.test_ratings_edit_update|0.3086
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_unrated_public_brazil_game|0.3088
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_home_auth|0.3100
zamboni.mkt.reviewers.tests.test_views.TestMiniManifestView.test_reviewer|0.3101
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_disabled_payments_action_links_with_payments|0.3113
zamboni.mkt.ratings.tests.test_views.TestCreate.test_not_rated|0.3115
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_rated_pending_brazil_game_message_for_user|0.3122
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_admin|0.3124
zamboni.mkt.reviewers.tests.test_views.TestMiniManifestView.test_wrong_version|0.3138
zamboni.mkt.ratings.tests.test_views.TestCreate.test_premium_add_review_link_dev|0.3148
zamboni.mkt.receipts.tests.test_views.TestInstall.test_record_logged_out|0.3154
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_permissions_token|0.3170
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_task_called_on_abuse_report|0.3178
zamboni.mkt.submit.tests.test_views.TestCreateWebAppFromManifest.test_allow_duplicate_domains_from_js|0.3187
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_refunds|0.3192
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_only_one_issue|0.3212
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_new_version_not_created|0.3222
zamboni.mkt.developers.tests.test_views.TestRefunds.test_not_premium|0.3226
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_install_not_premium|0.3236
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_review_premium_refunded|0.3239
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_xss|0.3244
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_install_has_uuid|0.3253
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_multiple_versions_reject_packaged|0.3258
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_client_data|0.3276
zamboni.mkt.inapp_pay.tests.test_views.TestPay.test_preauth_ok_solitude|0.3277
zamboni.mkt.ratings.tests.test_views.TestCreate.test_add_client_data_no_user_agent_match|0.3278
zamboni.mkt.developers.tests.test_views.TestIssueRefund.test_no_issue_after_decline|0.3290
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_remove_profile|0.3300
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_accept_good_locale|0.3301
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_no_apps|0.3319
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_developer|0.3327
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_regular_user|0.3330
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_disable_senior_reviewer|0.3333
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_reviewer|0.3334
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_partner|0.3345
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_admin|0.3346
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_rereview_to_disable_senior_reviewer|0.3358
zamboni.mkt.downloads.tests.test_views.TestDownload.test_disabled|0.3366
zamboni.mkt.developers.tests.test_views_payments.TestInappConfigReset.test_reset_requires_app_with_payments|0.3375
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_abuse_already_escalated|0.3385
zamboni.mkt.stats.tests.test_tasks.TestAlreadyIndexed.test_basic|0.3394
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_remove_profile_without_content|0.3413
zamboni.mkt.purchase.tests.test_views.TestPurchaseDetails.test_details_preauth|0.3415
zamboni.mkt.ratings.tests.test_views.TestCreate.test_no_reviews_premium_no_add_review_link|0.3418
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_upsell|0.3432
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_rated_public_brazil_game_ratings|0.3440
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_no_free|0.3443
zamboni.mkt.ratings.tests.test_views.TestCreate.test_reviews_premium_add_review_link|0.3449
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_home|0.3459
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_upsell_not_mine|0.3487
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_escalation_to_disable_senior_reviewer|0.3502
zamboni.mkt.stats.tests.test_views.TestGetSeriesColumn.test_basic_revenue|0.3504
zamboni.mkt.ratings.tests.test_views.TestCreate.test_reviews_premium_refunded|0.3510
zamboni.mkt.stats.tests.test_views.TestGetSeriesColumn.test_desc_order|0.3512
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_set_startdate|0.3523
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_remove_startdate|0.3532
zamboni.mkt.receipts.tests.test_views.TestInstall.test_not_record_addon|0.3534
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_refunds_already_escalated|0.3539
zamboni.mkt.ratings.tests.test_views.TestCreate.test_reviews_premium_edit_review_link|0.3541
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_multiple_refunds_same_user|0.3566
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_set_enddate|0.3577
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_edit_review_initial|0.3584
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_initial_paid|0.3591
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotalInapp.test_index|0.3591
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_as_developer|0.3593
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_set_region|0.3606
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_no_engaged_robots_for_invisible|0.3606
zamboni.mkt.developers.tests.test_views.TestResumeStep.test_no_resume_when_done|0.3610
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_get_categories|0.3623
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_remove_enddate|0.3625
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_upsell_wrong_status|0.3626
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_abuse_cleared_not_escalated|0.3638
zamboni.mkt.developers.tests.test_views.TestProfileStatusBar.test_remove_both|0.3648
zamboni.mkt.receipts.tests.test_views.TestInstall.test_record_metrics|0.3657
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_currency|0.3683
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_upsell_wrong_type|0.3695
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotal.test_index|0.3700
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_remove_upsell|0.3705
zamboni.mkt.submit.tests.test_views.TestDetails.test_unsaved_screenshot|0.3706
zamboni.mkt.receipts.tests.test_views.TestInstall.test_record_receipt|0.3708
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_app_created|0.3713
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_public_no_mozilla_contact|0.3725
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_no_paypal|0.3725
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_no_payment_data|0.3730
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_basic_summary|0.3736
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_paypal_ids|0.3741
zamboni.mkt.receipts.tests.test_views.TestInstall.test_record_install|0.3743
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_delete_featured_app|0.3751
zamboni.mkt.receipts.tests.test_views.TestInstall.test_log_metrics|0.3764
zamboni.mkt.receipts.tests.test_views.TestInstall.test_not_paid|0.3768
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_paid_for_anonymous|0.3770
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set|0.3781
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_payment_data|0.3783
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_success_edit|0.3786
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_set_currency_fail|0.3790
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_free_for_anonymous|0.3806
zamboni.mkt.developers.tests.test_views_paypal.TestPaypalResponse.test_payment_confirm_solitude|0.3814
zamboni.mkt.submit.tests.test_views.TestDetails.test_screenshot_required|0.3815
zamboni.mkt.submit.tests.test_views.TestDetails.test_homepage_url_invalid|0.3818
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_paykey_amount|0.3819
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_staff_access|0.3820
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_reject|0.3820
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_action_links_packaged|0.3821
zamboni.mkt.submit.tests.test_views.TestDetails.test_slug_required|0.3835
zamboni.mkt.submit.tests.test_views.TestDetails.test_privacy_policy_required|0.3836
zamboni.mkt.submit.tests.test_views.TestDetails.test_categories_required|0.3838
zamboni.mkt.submit.tests.test_views.TestDetails.test_name_required|0.3839
zamboni.mkt.submit.tests.test_views.TestDetails.test_support_url_invalid|0.3839
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_public_waiting_signs|0.3840
zamboni.mkt.submit.tests.test_views.TestDetails.test_support_email_required|0.3848
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_no_duplicate_payment_data|0.3853
zamboni.mkt.submit.tests.test_views.TestDetails.test_summary_length|0.3854
zamboni.mkt.submit.tests.test_views.TestDetails.test_device_types_invalid|0.3856
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_add|0.3868
zamboni.mkt.submit.tests.test_views.TestDetails.test_support_email_invalid|0.3873
zamboni.mkt.submit.tests.test_views.TestDetails.test_summary_required|0.3877
zamboni.mkt.submit.tests.test_views.TestDetails.test_name_length|0.3880
zamboni.mkt.submit.tests.test_views.TestDetails.test_slug_invalid|0.3881
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_302_for_anonymous|0.3885
zamboni.mkt.submit.tests.test_views.TestDetails.test_device_types_required|0.3894
zamboni.mkt.submit.tests.test_views.TestDetails.test_device_types_default_on_post|0.3895
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_inapp_counts|0.3921
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_public_signs|0.3942
zamboni.mkt.submit.tests.test_views.TestDetails.test_screenshot_or_video_required|0.3953
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceDaily.test_index|0.3957
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_permissions_token_solitude|0.3961
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_personal_differs_solitude|0.3968
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_pending_to_public_waiting|0.3984
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_edit_summary_escaping|0.4010
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_multiple_versions_reject_hosted|0.4019
zamboni.mkt.webapps.tests.test_tasks.TestUpdateManifest.test_version_updated|0.4033
zamboni.mkt.submit.tests.test_views.TestDetails.test_categories_max|0.4039
zamboni.mkt.receipts.tests.test_views.TestInstall.test_paid|0.4043
zamboni.mkt.detail.tests.test_views.TestDetail.test_upsell|0.4053
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_approved_refunds|0.4069
zamboni.mkt.account.tests.test_views.TestProfileSections.test_my_submissions|0.4072
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_requested_refunds|0.4079
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_uploadedicon_noresize|0.4094
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotalBySrc.test_index|0.4104
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotalByCurrency.test_index|0.4110
zamboni.mkt.receipts.tests.test_views.TestInstall.test_own_payments|0.4111
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotalInappBySource.test_index|0.4121
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_paid_for_developer|0.4129
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_free_for_developer|0.4130
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_version_list_packaged|0.4132
zamboni.mkt.receipts.tests.test_views.TestInstall.test_cef_logs|0.4132
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_refunds_cleared_not_escalated|0.4134
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_edit_default_locale_required_trans|0.4135
zamboni.mkt.receipts.tests.test_models.TestReceipt.test_receipt_packaged|0.4140
zamboni.mkt.reviewers.tests.test_views.TestAbuseReports.test_abuse_reports_list|0.4154
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_escalation_to_reject|0.4166
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceDailyInapp.test_index|0.4166
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_uploadedicon|0.4174
zamboni.mkt.receipts.tests.test_views.TestInstall.test_record_multiple_installs|0.4184
zamboni.mkt.receipts.tests.test_views.TestInstall.test_installed_client_data|0.4185
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_only_owner_can_edit|0.4223
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_not_themes|0.4223
zamboni.mkt.developers.tests.test_views_ownership.TestDeveloperRoleAccess.test_disable|0.4246
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_paid_for_reviewer|0.4264
zamboni.mkt.reviewers.tests.test_views.TestCannedResponses.test_no_addon|0.4271
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_success|0.4271
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_create|0.4279
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_zero_alltime_dl|0.4283
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_get_featured_apps|0.4293
zamboni.mkt.zadmin.tests.test_views.TestFeaturedApps.test_add_featured_app|0.4294
zamboni.mkt.receipts.tests.test_views.TestInstall.test_pending_free_for_reviewer|0.4304
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_403_for_non_editor|0.4321
zamboni.mkt.lookup.tests.test_views.TestAddonDownloadSummary.test_alltime_dl|0.4331
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_rereview_to_reject|0.4338
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_more_themes|0.4369
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_get_not_mine|0.4414
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_success_edit_user|0.4431
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_not_mine|0.4442
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_new_more_themes|0.4447
zamboni.mkt.account.tests.test_views.TestAbuse.test_add|0.4512
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_change_status_fails|0.4531
zamboni.mkt.developers.tests.test_views_versions.TestVersion.test_rejected|0.4565
zamboni.mkt.developers.tests.test_views.TestRefunds.test_is_premium|0.4566
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_roles_and_delete|0.4567
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_manifest_changed_same_domain_diff_path|0.4581
zamboni.mkt.developers.tests.test_views.TestAppBreadcrumbs.test_webapp_management_breadcrumbs|0.4659
zamboni.mkt.reviewers.tests.test_task.TestRefundsEscalationTask.test_older_refund_escalations_then_new|0.4680
zamboni.mkt.developers.tests.test_views_versions.TestEditVersion.test_post|0.4698
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_get_previews|0.4729
zamboni.mkt.site.tests.test_middleware.TestRegionMiddleware.test_accept_language|0.4750
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_cant_skip|0.4751
zamboni.mkt.ratings.tests.test_views.TestCreate.test_review_success_dup|0.4767
zamboni.mkt.ratings.tests.test_views.TestCreate.test_can_review_purchased|0.4768
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_no_reviews|0.4778
zamboni.mkt.developers.tests.test_views.TestMarketplace.test_replace_upsell|0.4786
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_no_categories|0.4788
zamboni.mkt.themes.tests.test_views.TestSubmitTheme.test_bad_hashes|0.4790
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_queue_count|0.4808
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_l10n_not_us_id_url|0.4816
zamboni.mkt.developers.tests.test_views.TestProfile.test_with_contributions_fields_required|0.4831
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_setup|0.4858
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_desktop_error_nice|0.4866
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_add_two|0.4875
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_no_desktop|0.4885
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_wrong_category|0.4919
zamboni.mkt.reviewers.tests.test_views.TestReviewApp.test_escalation_to_public|0.5010
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_verbs|0.5030
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_queue_count_senior_reviewer|0.5031
zamboni.mkt.site.tests.test_views.TestMozmarketJS.test_minify_with_yui|0.5057
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_support_not_logged_in|0.5064
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_change_status_passes|0.5076
zamboni.mkt.site.tests.test_views.TestMozmarketJS.test_minify|0.5077
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_disable|0.5078
zamboni.mkt.developers.tests.test_views.TestProfile.test_without_contributions_fields_optional|0.5121
zamboni.mkt.lookup.tests.test_views.TestAcctSummary.test_app_counts|0.5138
zamboni.mkt.developers.tests.test_views_ownership.TestEditAuthor.test_reorder_authors|0.5170
zamboni.mkt.webapps.tests.test_crons.TestWeeklyDownloads.test_addon|0.5179
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_admin_edit_manifest_url|0.5192
zamboni.mkt.ratings.tests.test_views.TestCreate.test_support_link|0.5331
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_action_links_with_payments|0.5387
zamboni.mkt.webapps.tests.test_models.TestWebapp.test_package_helpers|0.5412
zamboni.mkt.developers.tests.test_views.TestDeleteApp.test_delete_incomplete_manually|0.5427
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_public_waiting|0.5433
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_manifest_changed_dupe_app_domain|0.5435
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_screenshot_with_icon|0.5451
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact_mozilla_mails|0.5454
zamboni.mkt.developers.tests.test_views_versions.TestAddVersion.test_unique_version|0.5480
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_refund_remove|0.5495
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_refund_remove_passes|0.5511
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact|0.5520
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_skip|0.5525
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_inapp|0.5545
zamboni.mkt.developers.tests.test_views_versions.TestAddVersion.test_post|0.5550
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_icon_log|0.5561
zamboni.mkt.stats.tests.test_views.TestGetSeriesLine.test_revenue|0.5577
zamboni.mkt.stats.tests.test_views.TestGetSeriesLine.test_basic|0.5581
zamboni.mkt.stats.tests.test_views.TestGetSeriesLine.test_desc_order|0.5583
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_support_page_form|0.5624
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_302_for_anonymous|0.5643
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_support_not_mine|0.5676
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_bad_icons|0.5679
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact_mozilla_fails|0.5708
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact_fails|0.5725
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_no_refund_link|0.5733
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact_mozilla|0.5819
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_no_icons|0.5856
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_skip_fails|0.5860
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_instant|0.5861
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_keep|0.5864
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_instant_solitude|0.5875
zamboni.mkt.developers.tests.test_views_versions.TestVersionPackaged.test_delete_version|0.5879
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put|0.5900
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_contact_mails|0.5904
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_categories_worked|0.5918
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_put_desktop_worked|0.5922
zamboni.mkt.reviewers.tests.test_views.TestModeratedQueue.test_delete|0.6023
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_edit|0.6084
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_support_page_external_link|0.6100
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_403_for_non_editor|0.6116
zamboni.mkt.reviewers.tests.test_views.TestMiniManifestView.test_not_packaged|0.6147
zamboni.mkt.account.tests.test_views.TestProfileSections.test_my_submissions_pagination|0.6172
zamboni.mkt.developers.tests.test_views_ownership.TestDeveloperRoleAccess.test_urls|0.6176
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_support_site|0.6182
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_comment_doesnt_exist|0.6182
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_fails|0.6330
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_302_for_anonymous|0.6409
zamboni.mkt.webapps.tests.test_models.TestWebappManager.test_reviewed|0.6431
zamboni.mkt.submit.tests.test_views.TestCreatePackagedApp.test_packaged_app_not_unique_by_domain|0.6434
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_mails|0.6439
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_addon_doesnt_exist|0.6482
zamboni.mkt.reviewers.tests.test_task.TestAbuseEscalationTask.test_older_abuses_cleared_then_new|0.6483
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_data_uri|0.6527
zamboni.mkt.submit.tests.test_views.TestDetails.test_name_unique_strip|0.6540
zamboni.mkt.submit.tests.test_views.TestDetails.test_name_unique_case|0.6557
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_manifest_with_any_extension|0.6562
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_post_app_redirect|0.6580
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_author_doesnt_exist|0.6585
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_version_from_uploaded_manifest|0.6598
zamboni.mkt.developers.tests.test_views.TestManageLinks.test_refunds_link_support|0.6605
zamboni.mkt.submit.tests.test_views.TestDetails.test_name_unique|0.6610
zamboni.mkt.submit.tests.test_views.TestCreatePackagedApp.test_post_app_redirect|0.6618
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request|0.6631
zamboni.mkt.developers.tests.test_views.TestManageLinks.test_refunds_link_viewer|0.6659
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_cached_manifest_is_cached|0.6750
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_comment_exists|0.6758
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_request_info_logs|0.6773
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_escalate_logs|0.6776
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_addon_missing|0.6810
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_get_manifest_json|0.6817
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_403_for_non_editor|0.6912
zamboni.mkt.api.tests.test_handlers.TestAppStatusHandler.test_status|0.6941
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_cached_manifest_contents|0.6956
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_request_instant_fails|0.6977
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_addon_exists|0.7034
zamboni.mkt.developers.tests.test_tasks.TestFetchIcon.test_hosted_icon|0.7067
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_already_refunded_request|0.7084
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_author_exists|0.7107
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_invalid_page|0.7132
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_no_txnid_request|0.7168
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_xss|0.7195
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_add_another|0.7204
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_queue_count|0.7217
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_escalated_not_in_queue|0.7237
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_flag_comment|0.7246
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_hint_for_same_manifest|0.7250
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_package_path|0.7268
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_template_links|0.7288
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_flag_info|0.7297
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_imageassets|0.7313
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_no_hint_for_same_manifest_different_author|0.7347
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_queue_count_senior_reviewer|0.7404
zamboni.mkt.developers.tests.test_views_edit.TestEditDetails.test_exclude_region|0.7420
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_basic|0.7437
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_flag_premium_app|0.7529
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_addon_by_slug_exists|0.7533
zamboni.mkt.developers.tests.test_views.TestAppDashboard.test_action_links|0.7557
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_end_filter_wrong|0.7595
zamboni.mkt.submit.tests.test_views.TestDetails.test_description_optional|0.7635
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_get|0.7701
zamboni.mkt.submit.tests.test_views.TestDetails.test_support_url_optional|0.7721
zamboni.mkt.submit.tests.test_views.TestDetails.test_homepage_url_optional|0.7754
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_no_hint|0.7806
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_action_buttons_public|0.7835
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_action_buttons_reject|0.7854
zamboni.mkt.submit.tests.test_views.TestDetails.test_games_default_excluded_in_brazil|0.7897
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_search_app_soft_deleted|0.7910
zamboni.mkt.ratings.tests.test_cron.TestEmailDailyRatings.test_emails_goes_out|0.7946
zamboni.mkt.submit.tests.test_views.TestCreatePackagedApp.test_app_from_uploaded_package|0.7966
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_order|0.7972
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_action_buttons_public_senior_reviewer|0.8016
zamboni.mkt.submit.tests.test_views.TestDetails.test_categories_add|0.8097
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_imageasset_edit|0.8134
zamboni.mkt.api.tests.test_handlers.TestAppCreateHandler.test_dehydrate|0.8147
zamboni.mkt.submit.tests.test_views.TestDetails.test_success|0.8147
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_302_for_anonymous|0.8153
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_imageasset_add|0.8155
zamboni.mkt.submit.tests.test_views.TestDetails.test_categories_remove|0.8202
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_302_for_anonymous|0.8210
zamboni.mkt.stats.tests.test_tasks.TestIndexFinanceTotalInappByCurrency.test_index|0.8374
zamboni.mkt.webapps.tests.test_models.TestWebappManager.test_unreviewed|0.8447
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_addon_deleted|0.8713
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_403_for_non_editor|0.8728
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_302_for_anonymous|0.8736
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_403_for_non_editor|0.8738
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_no_access_regular_reviewer|0.8764
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_addon_deleted|0.8795
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_reorder|0.8955
zamboni.mkt.submit.tests.test_views.TestDetails.test_clashing_locale|0.8968
zamboni.mkt.developers.tests.test_views.TestAppDashboardSorting.test_newest_sort|0.9011
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_queue_viewing_ping|0.9025
zamboni.mkt.themes.tests.test_views.TestCategoryLandingTheme.test_bad_cat|0.9071
zamboni.mkt.ratings.tests.test_views.TestCreate.test_body_has_url|0.9134
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_non_public_app_redirect|0.9225
zamboni.mkt.submit.tests.test_views.TestDetails.test_icon|0.9289
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_403_for_non_editor|0.9361
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_invalid_page|0.9369
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_action_buttons_public|0.9403
zamboni.mkt.support.tests.test_views.TestRequestSupport.test_refund_link|0.9414
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_escalated_not_in_queue|0.9418
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_action_buttons_public|0.9426
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_queue_count|0.9434
zamboni.mkt.themes.tests.test_views.TestCategoryLandingTheme.test_no_cat|0.9453
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_queue_count|0.9456
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_queue_count|0.9488
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_invalid_page|0.9493
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_flag_info|0.9511
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_flag_comment|0.9521
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_template_links|0.9548
zamboni.mkt.submit.tests.test_views.TestDetails.test_screenshot|0.9552
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_escalated_not_in_queue|0.9555
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_template_links|0.9559
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_devices|0.9564
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_action_buttons_public_senior_reviewer|0.9578
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_app_from_uploaded_manifest|0.9605
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_flag_comment|0.9626
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_flag_info|0.9737
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_queue_count_senior_reviewer|0.9741
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_flag_comment|0.9764
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_action_buttons_reject|0.9792
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_flag_info|0.9798
zamboni.mkt.developers.tests.test_views_edit.TestEditMedia.test_edit_preview_delete|0.9825
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_action_buttons_reject|0.9829
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_flag_premium_app|0.9846
zamboni.mkt.reviewers.tests.test_views.TestEscalationQueue.test_flag_packaged_app|0.9857
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_flag_premium_app|0.9863
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_abuse|0.9876
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_flag_packaged_app|0.9896
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_only_updates_in_queue|0.9901
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_flag_packaged_app|0.9908
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_xss_in_queue|0.9909
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_flag_premium_app|0.9914
zamboni.mkt.themes.tests.test_views.TestCategoryLandingTheme.test_good_cat|0.9966
zamboni.mkt.site.tests.test_middleware.TestLocaleMiddleware.test_accept_language|0.9998
zamboni.mkt.themes.tests.test_views.TestCategoryLandingTheme.test_popular|1.0018
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_template_links|1.0180
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_payments|1.0295
zamboni.mkt.reviewers.tests.test_views.TestReviewLog.test_end_filter|1.0363
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_action_buttons_rejected|1.0398
zamboni.mkt.submit.tests.test_views.TestCreateWebApp.test_file_from_uploaded_manifest|1.0429
zamboni.mkt.submit.tests.test_views.TestCreateWebAppFromManifest.test_allow_duplicate_domains|1.0449
zamboni.mkt.reviewers.tests.test_views.TestUpdateQueue.test_flag_packaged_app|1.0594
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_private_app_anonymous|1.0636
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_get_manifest_json_w_file|1.0798
zamboni.mkt.webapps.tests.test_models.TestPackagedManifest.test_get_manifest_json_multiple_versions|1.0825
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_non_public_app_owner_no_redirect|1.0889
zamboni.mkt.developers.tests.test_views.TestAppDashboardSorting.test_default_sort|1.0915
zamboni.mkt.developers.tests.test_views_edit.TestEditBasic.test_view_manifest_url_default|1.1362
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_action_buttons_pending|1.1479
zamboni.mkt.webapps.tests.test_models.TestManifest.test_get_manifest_json|1.1501
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_public_app_anonymous|1.1584
zamboni.mkt.submit.tests.test_views.TestDetails.test_other_categories_are_not_excluded|1.1692
zamboni.mkt.submit.tests.test_views.TestDetails.test_categories_add_and_remove|1.1872
zamboni.mkt.purchase.tests.test_views.TestPurchaseEmbedded.test_not_has_purchased|1.1989
zamboni.mkt.reviewers.tests.test_views.TestRereviewQueue.test_invalid_page|1.2183
zamboni.mkt.reviewers.tests.test_views.TestAppQueue.test_queue_count_senior_reviewer|1.2221
zamboni.mkt.api.tests.test_handlers.TestAddValidationHandler.test_good|1.3170
zamboni.mkt.themes.tests.test_views.TestPersonaDetailPage.test_other_themes|1.3385
zamboni.mkt.reviewers.tests.test_views.TestReviewersHome.test_302_for_anonymous|1.3617
zamboni.mkt.developers.tests.test_views.TestRefunds.test_queues|1.3726
zamboni.mkt.developers.tests.test_views.TestRefunds.test_tables|1.3761
zamboni.mkt.developers.tests.test_views.TestRefunds.test_refunds_sorting|1.3906
zamboni.mkt.reviewers.tests.test_views.TestReviewersHome.test_403_for_non_editor|1.4132
zamboni.mkt.reviewers.tests.test_views.TestReviewersHome.test_reviewer_leaders|1.4653
zamboni.mkt.developers.tests.test_views.TestRefunds.test_timestamps|1.4666
zamboni.mkt.reviewers.tests.test_views.TestReviewersHome.test_stats_waiting|1.5429
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_private_app_no_groups|1.9080
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_public_app_stats_group|1.9543
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_public_app_contrib_stats_group|1.9875
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_private_app_contrib_stats_group|1.9877
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_private_app_stats_group|1.9879
zamboni.mkt.stats.tests.test_views.TestStatsPermissions.test_public_app_no_groups|1.9960
<nose.suite.ContextSuite context=TestSuggestions>:setup|2.0023
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_non_game_regular_user|2.2775
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_unrated_game_regular_user|2.3187
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_unrated_game_reviewer|2.3215
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_rated_game_admin|2.3248
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_unrated_game_admin|2.3253
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_unrated_game_partner|2.3273
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_rated_game_regular_user|2.3425
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_rated_game_developer|2.3429
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_rated_game_partner|2.3521
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_rated_game_reviewer|2.3530
zamboni.mkt.webapps.tests.test_models.TestIsVisible.test_unrated_game_developer|2.7253
zamboni.mkt.detail.tests.test_views.TestDetailPagePermissions.test_unrated_brazil_game_apply_message_for_owner_or_admin|2.7614
zamboni.mkt.developers.tests.test_views.TestAppDashboardSorting.test_pagination|2.9554
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_user_review_history|3.6600
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_expiry_update|3.7162
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_single_basic|3.8041
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_permissions_reviewer|3.9595
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_commit|4.0853
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_expiry|4.1472
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_basic_queue|4.4286
zamboni.mkt.reviewers.tests.test_views.TestThemeReviewQueue.test_top_off|4.8959"""

import re

for line in data.split('\n'):
    text = re.sub(' +', ' ', line)
    print '<tr>'
    for bit in text.split('|'):
        print '    <td>' + bit + '</td>'
    print '</tr>'
